@@ -56,13 +56,22 @@ proc xcircuit::getsubckttext {name} {
 proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    global XCOps
 
+   set techname [.dialog.techself.techselect cget -text]
    set symbolname [.dialog.textent.txt get]
 
+   if {[string first :: $symbolname] >= 0} {	;# symbolname has tech name embedded
+      set techname ""
+   } elseif {[string first ( $techname] >= 0} {	;# "(user)" specified
+      set techname "::"
+   } elseif {[string first :: $techname] < 0} {
+      set techname "${techname}::"
+   }
+
    # If "filename" is specified then we have a netlist, not a schematic.
    # Therefore, create an object but don't use xcircuit::symbol
 
    if {$filename == ""} {
-      xcircuit::symbol make $symbolname $XCOps(library);
+      xcircuit::symbol make ${techname}${symbolname} $XCOps(library);
       set schematicname [schematic get]
       set noschem 0
    } else {
@@ -106,7 +115,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
 
    if {$noschem == 1} {
       select $sbox
-      set handle [object make $symbolname $XCOps(library)]
+      set handle [object make ${techname}${symbolname} $XCOps(library)]
       push $handle
    }
 
@@ -126,6 +135,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       label $nlab type normal
       label $nlab justify right
       incr y $pinspace
+      deselect selected
    }
    set x [expr -$hwidth - $qtrspace]
    set y [expr -($leftpins - 1) * $halfspace]
@@ -141,6 +151,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       label $nlab type normal
       label $nlab justify left
       incr y $pinspace
+      deselect selected
    }
    set y [expr -$hheight -$qtrspace]
    set x [expr -($botpins - 1) * $halfspace]
@@ -157,6 +168,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       label $nlab type normal
       label $nlab justify left
       incr x $pinspace
+      deselect selected
    }
    set y [expr $hheight + $qtrspace]
    set x [expr -($toppins - 1) * $halfspace]
@@ -173,15 +185,16 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       label $nlab type normal
       label $nlab justify left
       incr x $pinspace
+      deselect selected
    }
 
-   deselect
+   deselect selected
    set nlab [label make "$symbolname" {0 0}]
    label $nlab justify middle
    label $nlab justify center
    element $nlab color set blue
 
-   deselect
+   deselect selected
    parameter make substring idx "?"
    parameter make substring class "X"
    if {$schematicname == $symbolname} {
@@ -193,7 +206,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    set nlab [label make "{Parameter class} {Parameter idx}" "0 -$pinspace"]
    label $nlab justify center
    element $nlab color set blue
-   deselect
+   deselect selected
 
    # Determine if the schematic already has a "subckt" line.  If so,
    # attempt to arrange the pin ordering from it.  If not, create one.
@@ -206,9 +219,17 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
 
    if {$subckttext == ""} {
       set subckttext [list {Text "spice1:.subckt %n"}]
+      set pstring ""
       foreach j $pinlabels {
-         lappend subckttext "$j"
+	 if {[string length $pstring] > 60} {
+            lappend subckttext [subst {Text "$pstring"}]
+	    lappend subckttext {Return}
+	    set pstring "+"
+	 }
+	 set pstring [join [list $pstring "$j"]]   ;# preserves whitespace
       }
+      lappend subckttext [subst {Text "$pstring"}]
+
       if {$noschem == 0} {
          schematic goto
          set bbox [join [page bbox all]] 
@@ -216,6 +237,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
          set y [expr [lindex $bbox 1] - $pinspace]
          set nlab [label make info "$subckttext" "$x $y"] 
          label $nlab justify center
+         deselect selected
          set y [expr $y - $pinspace]
          set nlab [label make info "spice-1:.ends" "$x $y"] 
          symbol goto
@@ -250,12 +272,12 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
 
    set y [expr -$hheight - 3 * $pinspace]
 
-   deselect
+   deselect selected
    set nlab [label make info "$itext" "0 $y"] 
    label $nlab justify center
 
    if {$noschem == 1} {
-      deselect
+      deselect selected
       if {[string index $filename 0] != "/"} {
 	 set filename [join [concat [pwd] $filename] "/"]
       }
@@ -264,11 +286,11 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       lappend itext [subst {Text "$filename"}]
       set nlab [label make info "$itext" "0 $y"]
       label $nlab justify center
-      deselect
+      deselect selected
       pop
    } else {
       library $XCOps(library) compose
-      deselect
+      deselect selected
       symbol goto
       zoom view
    }
@@ -288,7 +310,7 @@ proc xcircuit::getpinlist {schematicname} {
 
    if {$subckttext == {}} {
       set pinlist {}
-      deselect
+      deselect selected
       set objlist [object parts]
       
       foreach j $objlist {
@@ -296,7 +318,14 @@ proc xcircuit::getpinlist {schematicname} {
          if {$etype == "Label"} {
 	    set ltype [label $j type]
 	    if {$ltype == "local" || $ltype == "global"} {
-	       lappend pinlist [label $j text]
+
+	       # Avoid netlist-generated pins by rejecting labels that
+	       # don't start with a font specifier.
+
+	       set subtype [lindex [lindex [lindex [label $j list] 0] 0] 0]
+	       if {$subtype == "Font"} {
+	          lappend pinlist [label $j text]
+	       }
 	    }
 	 }
       }
@@ -304,7 +333,7 @@ proc xcircuit::getpinlist {schematicname} {
    } else {
       set pinlist [lrange [lindex $subckttext 0] 2 end]
    }
-   deselect
+   deselect selected
    return $pinlist
 }
 
@@ -409,8 +438,6 @@ proc xcircuit::movepinbottom {} {
 
 proc xcircuit::addpinarranger {w {pinlist {}}} {
 
-   xcircuit::removepinarranger ${w}
-
    frame ${w}.pinself
    frame ${w}.pinself.left
    frame ${w}.pinself.top
@@ -537,7 +564,7 @@ proc xcircuit::removepinarranger {w} {
 
 proc xcircuit::popupdialog {} {
    xcircuit::removepinarranger .dialog
-   xcircuit::removeliblist .dialog
+   xcircuit::removelists .dialog
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -555,20 +582,10 @@ proc xcircuit::promptmakesymbol {{name ""}} {
           wm withdraw .dialog}
   .dialog.textent.title.field configure -text "Confirm symbol name:"
   .dialog.textent.txt delete 0 end
-  # Prepend technology to name, if technology is set
-  if {![catch {set techprefix $XCOps(technology)}]} {
-     if {[string match $techprefix {}]} {
-	set techprefix ""
-     } elseif {[string match $techprefix (user)]} {
-	set techprefix "::"
-     } else {
-	set techprefix [join [list $techprefix ::] ""]
-     }
-  } else {
-     set techprefix ""
-  }
-  .dialog.textent.txt insert 0 ${techprefix}${name}
+  .dialog.textent.txt insert 0 $name
+
   xcircuit::popupdialog
+  xcircuit::addtechlist .dialog "Technology: "
   xcircuit::addliblist .dialog "Place in: "
   xcircuit::addpinarranger .dialog
 }        
@@ -585,7 +602,8 @@ proc xcircuit::spice2symbol {filename {subcktname ""}} {
   set f [open $filename]
   set infolabel ""
   while {[gets $f line] >= 0} {
-     if {[string first .subckt $line] == 0} {
+     set dnline [string tolower $line]
+     if {[string first .subckt $dnline] == 0} {
 	while {[gets $f nextline] >= 0} {
 	   if {[string first + $nextline] != 0} {break}
 	   append line [string range $nextline 1 end]
@@ -627,7 +645,7 @@ proc xcircuit::promptspicesymbol {} {
   .filelist.textent.title.field configure -text "Select spice file to parse:"
   .filelist.textent.txt delete 0 end
   xcircuit::popupfilelist
-  xcircuit::removeliblist .filelist
+  xcircuit::removelists .filelist
 }
 
 #---------------------------------------------------------------------------
