@@ -49,6 +49,7 @@ extern XCWindowData *areawin;
 extern char _STR[150];
 extern short fontcount;
 extern fontinfo *fonts;
+extern Boolean was_preselected;
 
 /*---------------------------------------------------------*/
 /* Find the Helvetica font for use in labeling the objects */
@@ -58,6 +59,8 @@ short findhelvetica()
 {
    short fval;
 
+   if (fontcount == 0) loadfontfile("Helvetica");
+
    for (fval = 0; fval < fontcount; fval++)
       if (!strcmp(fonts[fval].psname, "Helvetica"))
 	 break; 
@@ -1638,6 +1641,7 @@ void catalog_op(int op, int x, int y)
 	          }
 	          else {
                      eventmode = MOVE_MODE;
+		     was_preselected = FALSE;
 		     /* This is a hack, but avoids having to define a	*/
 		     /* separate event type for a move following a	*/
 		     /* library selection, just so we can handle	*/
