@@ -1463,8 +1463,11 @@ void setfontstyle(xcWidget w, pointertype value, labelptr settext)
          }
       }
 
-      /* otherwise, look for the last font used in the string */
-      tc = findcurfont(areawin->textpos - 2, settext->string, areawin->topinstance);
+      /* Otherwise, look for the last font used in the string */
+      /* Fix by Dimitri Princen.  Was areawin->textpos - 2; was there a */
+      /* reason for that?						*/
+
+      tc = findcurfont(areawin->textpos, settext->string, areawin->topinstance);
    }
    else tc = areawin->psfont;
 
